#!/usr/bin/python3
"""
## © University of Southampton IT Innovation Centre, 2018
##
## Copyright in this software belongs to University of Southampton
## IT Innovation Centre of Gamma House, Enterprise Road,
## Chilworth Science Park, Southampton, SO16 7NS, UK.
##
## This software may not be used, sold, licensed, transferred, copied
## or reproduced in whole or in part in any manner or form or in or
## on any media by any person other than in accordance with the terms
## of the Licence Agreement supplied with the software, or otherwise
## without the prior written consent of the copyright owners.
##
## This software is distributed WITHOUT ANY WARRANTY, without even the
## implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE, except where stated in the Licence Agreement supplied with
## the software.
##
##      Created By :            Nikolay Stanchev
##      Created Date :          22-08-2018
##      Created for Project :   FLAME
"""

from time import sleep
from pytest import fixture
from subprocess import Popen, DEVNULL
from os.path import join, dirname, exists
from os import kill, makedirs
from shutil import rmtree
from signal import SIGKILL
from json import load
from pkg_resources import resource_filename
from clmctest.alerts.alert_handler_server import LOG_TEST_FOLDER_PATH


@fixture(scope="module")
def rspec_config():
    """
    Reads the service configuration deployed for the integration tests.

    :return: the python object representing the read JSON file
    """

    rspec = resource_filename('clmctest', 'rspec.json')
    print("\nrspec file: {0}".format(rspec))

    with open(rspec, 'r') as stream:
        data_loaded = load(stream)
    return data_loaded


@fixture(autouse=True, scope="module")
def set_up_tear_down_fixture():
    """
    Set up/tear down fixture for the alerts integration test.
    """

    if exists(LOG_TEST_FOLDER_PATH):
        rmtree(LOG_TEST_FOLDER_PATH)  # clean out the log directory
    makedirs(LOG_TEST_FOLDER_PATH)  # create the log directory

    print("\nStarting alert handler HTTP server...")
    http_server_file = join(dirname(__file__), "alert_handler_server.py")
    p = Popen(["python3", http_server_file], stdout=DEVNULL, stderr=DEVNULL)
    process_id = p.pid
    sleep(1)
    print("Server started with PID {0}".format(process_id))

    yield

    print("\nKilling process with PID {0}".format(process_id))
    kill(process_id, SIGKILL)
    if exists(LOG_TEST_FOLDER_PATH):
        rmtree(LOG_TEST_FOLDER_PATH)
